@@ -14,6 +14,8 @@ import platform
 import shutil
 import subprocess
 import sys
+from pathlib import Path
+
 from os.path import basename
 from os.path import join as pjoin
 from os.path import normpath
@@ -22,6 +24,7 @@ from jupyter_core.paths import ENV_JUPYTER_PATH, SYSTEM_JUPYTER_PATH, jupyter_da
 from jupyter_core.utils import ensure_dir_exists
 from jupyter_server.extension.serverextension import ArgumentConflict
 from jupyterlab_server.config import get_federated_extensions
+from tomli import load
 
 from .commands import _test_overlap
 
@@ -191,6 +194,9 @@ def build_labextension(
     """Build a labextension in the given path"""
     if core_path is None:
         core_path = osp.join(HERE, "staging")
+    else:
+        core_path = str(Path(core_path).resolve())
+
     ext_path = osp.abspath(path)
 
     if logger:
@@ -215,6 +221,8 @@ def watch_labextension(
     """Watch a labextension in a given path"""
     if core_path is None:
         core_path = osp.join(HERE, "staging")
+    else:
+        core_path = str(Path(core_path).resolve())
     ext_path = osp.abspath(path)
 
     if logger:
@@ -419,18 +427,28 @@ def _get_labextension_metadata(module):
     except Exception as exc:
         errors.append(exc)
 
-    # Try getting the package name from setup.py
-    try:
-        package = (
-            subprocess.check_output([sys.executable, "setup.py", "--name"], cwd=mod_path)
-            .decode("utf8")
-            .strip()
-        )
-    except subprocess.CalledProcessError:
-        raise FileNotFoundError(
-            "The Python package `{}` is not a valid package, "
-            "it is missing the `setup.py` file.".format(module)
-        )
+     # Try to get the package name
+    package = None
+
+    # Try getting the package name from pyproject.toml
+    if os.path.exists(os.path.join(mod_path, "pyproject.toml")):
+        with open(os.path.join(mod_path, "pyproject.toml"), "rb") as fid:
+            data = load(fid)
+        package = data.get("project", {}).get("name")
+
+    # Try getting the package name from setup.py invocation.
+    if not package:
+        try:
+            package = (
+                subprocess.check_output([sys.executable, "setup.py", "--name"], cwd=mod_path)
+                .decode("utf8")
+                .strip()
+            )
+        except subprocess.CalledProcessError:
+            raise FileNotFoundError(
+                "The Python package `{}` is not a valid package, "
+                "it is missing the `setup.py` file.".format(module)
+            )
 
     # Make sure the package is installed
     import pkg_resources
